# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/math.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/math.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprotos/model/v1/math.proto\x12\x08v1.model\"\x18\n\x07Numeric\x12\r\n\x05value\x18\x01 \x01(\x01\"=\n\x0fNumericSetEntry\x12\r\n\x05value\x18\x01 \x01(\x01\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"9\n\nNumericSet\x12+\n\x08numerics\x18\x01 \x03(\x0b\x32\x19.v1.model.NumericSetEntry\"!\n\x03\x42it\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"%\n\x06\x42itset\x12\x1b\n\x04\x62its\x18\x01 \x03(\x0b\x32\r.v1.model.Bit\"N\n\x05Twist\x12!\n\x06linear\x18\x01 \x01(\x0b\x32\x11.v1.model.Vector3\x12\"\n\x07\x61ngular\x18\x02 \x01(\x0b\x32\x11.v1.model.Vector3\"[\n\tTransform\x12&\n\x0btranslation\x18\x01 \x01(\x0b\x32\x11.v1.model.Vector3\x12&\n\x08rotation\x18\x02 \x01(\x0b\x32\x14.v1.model.Quaternion\"c\n\x0eTransformFrame\x12\x14\n\x0cparent_frame\x18\x01 \x01(\t\x12\x13\n\x0b\x63hild_frame\x18\x02 \x01(\t\x12&\n\ttransform\x18\x03 \x01(\x0b\x32\x13.v1.model.Transform\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01w\x18\x04 \x01(\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.math_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_NUMERIC']._serialized_start=40
  _globals['_NUMERIC']._serialized_end=64
  _globals['_NUMERICSETENTRY']._serialized_start=66
  _globals['_NUMERICSETENTRY']._serialized_end=127
  _globals['_NUMERICSET']._serialized_start=129
  _globals['_NUMERICSET']._serialized_end=186
  _globals['_BIT']._serialized_start=188
  _globals['_BIT']._serialized_end=221
  _globals['_BITSET']._serialized_start=223
  _globals['_BITSET']._serialized_end=260
  _globals['_TWIST']._serialized_start=262
  _globals['_TWIST']._serialized_end=340
  _globals['_TRANSFORM']._serialized_start=342
  _globals['_TRANSFORM']._serialized_end=433
  _globals['_TRANSFORMFRAME']._serialized_start=435
  _globals['_TRANSFORMFRAME']._serialized_end=534
  _globals['_VECTOR3']._serialized_start=536
  _globals['_VECTOR3']._serialized_end=578
  _globals['_POINT']._serialized_start=580
  _globals['_POINT']._serialized_end=620
  _globals['_QUATERNION']._serialized_start=622
  _globals['_QUATERNION']._serialized_end=678
# @@protoc_insertion_point(module_scope)
