# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/event.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/model/v1/event.proto\x12\x08v1.model\"\xc0\x02\n\x05\x45vent\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x15\n\rend_timestamp\x18\x08 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x13\n\x0bstream_type\x18\x04 \x01(\t\x12\x1c\n\x14notification_enabled\x18\x05 \x01(\x08\x12$\n\x08severity\x18\t \x01(\x0e\x32\x12.v1.model.Severity\x12\n\n\x02id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x18\n\x10\x65vent_trigger_id\x18\x0c \x01(\t\x12\'\n\x04tags\x18\x06 \x03(\x0b\x32\x19.v1.model.Event.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"\xa2\x01\n\x17\x41gentEventConfiguration\x12\x33\n\x0e\x65vent_triggers\x18\x01 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12<\n\x17stateful_event_triggers\x18\x03 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12\x14\n\x0clast_updated\x18\x02 \x01(\x03\"\xd6\x02\n\x11\x41gentEventTrigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\x03\x12&\n\tcondition\x18\x04 \x01(\x0b\x32\x13.v1.model.Condition\x12*\n\rexitCondition\x18\x05 \x01(\x0b\x32\x13.v1.model.Condition\x12\x19\n\x11isStatefulTrigger\x18\x06 \x01(\x08\x12L\n\x1cstatefulTriggerConfiguration\x18\x07 \x01(\x0b\x32&.v1.model.StatefulTriggerConfiguration\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\x15\n\rmessageFormat\x18\x0b \x01(\t\x12\x10\n\x08severity\x18\t \x01(\t\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\"\x85\x04\n\tCondition\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12;\n\x08presence\x18\x02 \x01(\x0b\x32\'.v1.model.PresenceEventTriggerConditionH\x00\x12=\n\tthreshold\x18\x03 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerConditionH\x00\x12\x35\n\x05regex\x18\x04 \x01(\x0b\x32$.v1.model.RegexEventTriggerConditionH\x00\x12\x37\n\x06\x62itset\x18\x05 \x01(\x0b\x32%.v1.model.BitsetEventTriggerConditionH\x00\x12\x39\n\x07\x62\x61ttery\x18\x06 \x01(\x0b\x32&.v1.model.BatteryEventTriggerConditionH\x00\x12<\n\x07numeric\x18\x07 \x01(\x0b\x32).v1.model.NumericSetEventTriggerConditionH\x00\x12\x33\n\x04json\x18\x08 \x01(\x0b\x32#.v1.model.JsonEventTriggerConditionH\x00\x12\x41\n\x0b\x61utoresolve\x18\t \x01(\x0b\x32*.v1.model.AutoresolveEventTriggerConditionH\x00\x42\x0b\n\tcondition\"\x1f\n\x1dPresenceEventTriggerCondition\"\"\n AutoresolveEventTriggerCondition\"^\n\x1eThresholdEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ThresholdOperator\"^\n\x10NumericCondition\x12\r\n\x05label\x18\x01 \x01(\t\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\"\x80\x01\n\x1fNumericSetEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.NumericCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"\xa5\x01\n\x10\x42\x61tteryCondition\x12%\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x16.v1.model.BatteryField\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\x12-\n\x08operator\x18\x03 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"}\n\x1c\x42\x61tteryEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.BatteryCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"+\n\x1aRegexEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\t\"\x7f\n\x1b\x42itsetEventTriggerCondition\x12\x31\n\x0e\x62it_conditions\x18\x01 \x03(\x0b\x32\x19.v1.model.BitsetCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\";\n\x0f\x42itsetCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04true\x18\x02 \x01(\x08\x12\r\n\x05\x66\x61lse\x18\x03 \x01(\x08\",\n\x19JsonEventTriggerCondition\x12\x0f\n\x07jqQuery\x18\x01 \x01(\t\"W\n\x1cStatefulTriggerConfiguration\x12\x1b\n\x13\x65mitOnEnteringState\x18\x01 \x01(\x08\x12\x1a\n\x12\x65mitOnLeavingState\x18\x02 \x01(\x08*:\n\x08Severity\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0c\n\x08\x43RITICAL\x10\x03*D\n\x0c\x42\x61tteryField\x12\n\n\x06\x43harge\x10\x00\x12\x0b\n\x07\x43urrent\x10\x01\x12\x0e\n\nPercentage\x10\x02\x12\x0b\n\x07Voltage\x10\x03*F\n\x11ThresholdOperator\x12\x06\n\x02LT\x10\x00\x12\x07\n\x03LTE\x10\x01\x12\x06\n\x02GT\x10\x02\x12\x07\n\x03GTE\x10\x03\x12\x06\n\x02\x45Q\x10\x04\x12\x07\n\x03NEQ\x10\x05*%\n\x11\x43onditionOperator\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_EVENT_TAGSENTRY']._loaded_options = None
  _globals['_EVENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SEVERITY']._serialized_start=2451
  _globals['_SEVERITY']._serialized_end=2509
  _globals['_BATTERYFIELD']._serialized_start=2511
  _globals['_BATTERYFIELD']._serialized_end=2579
  _globals['_THRESHOLDOPERATOR']._serialized_start=2581
  _globals['_THRESHOLDOPERATOR']._serialized_end=2651
  _globals['_CONDITIONOPERATOR']._serialized_start=2653
  _globals['_CONDITIONOPERATOR']._serialized_end=2690
  _globals['_EVENT']._serialized_start=42
  _globals['_EVENT']._serialized_end=362
  _globals['_EVENT_TAGSENTRY']._serialized_start=313
  _globals['_EVENT_TAGSENTRY']._serialized_end=356
  _globals['_AGENTEVENTCONFIGURATION']._serialized_start=365
  _globals['_AGENTEVENTCONFIGURATION']._serialized_end=527
  _globals['_AGENTEVENTTRIGGER']._serialized_start=530
  _globals['_AGENTEVENTTRIGGER']._serialized_end=872
  _globals['_CONDITION']._serialized_start=875
  _globals['_CONDITION']._serialized_end=1392
  _globals['_PRESENCEEVENTTRIGGERCONDITION']._serialized_start=1394
  _globals['_PRESENCEEVENTTRIGGERCONDITION']._serialized_end=1425
  _globals['_AUTORESOLVEEVENTTRIGGERCONDITION']._serialized_start=1427
  _globals['_AUTORESOLVEEVENTTRIGGERCONDITION']._serialized_end=1461
  _globals['_THRESHOLDEVENTTRIGGERCONDITION']._serialized_start=1463
  _globals['_THRESHOLDEVENTTRIGGERCONDITION']._serialized_end=1557
  _globals['_NUMERICCONDITION']._serialized_start=1559
  _globals['_NUMERICCONDITION']._serialized_end=1653
  _globals['_NUMERICSETEVENTTRIGGERCONDITION']._serialized_start=1656
  _globals['_NUMERICSETEVENTTRIGGERCONDITION']._serialized_end=1784
  _globals['_BATTERYCONDITION']._serialized_start=1787
  _globals['_BATTERYCONDITION']._serialized_end=1952
  _globals['_BATTERYEVENTTRIGGERCONDITION']._serialized_start=1954
  _globals['_BATTERYEVENTTRIGGERCONDITION']._serialized_end=2079
  _globals['_REGEXEVENTTRIGGERCONDITION']._serialized_start=2081
  _globals['_REGEXEVENTTRIGGERCONDITION']._serialized_end=2124
  _globals['_BITSETEVENTTRIGGERCONDITION']._serialized_start=2126
  _globals['_BITSETEVENTTRIGGERCONDITION']._serialized_end=2253
  _globals['_BITSETCONDITION']._serialized_start=2255
  _globals['_BITSETCONDITION']._serialized_end=2314
  _globals['_JSONEVENTTRIGGERCONDITION']._serialized_start=2316
  _globals['_JSONEVENTTRIGGERCONDITION']._serialized_end=2360
  _globals['_STATEFULTRIGGERCONFIGURATION']._serialized_start=2362
  _globals['_STATEFULTRIGGERCONFIGURATION']._serialized_end=2449
# @@protoc_insertion_point(module_scope)
