# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import commands_pb2 as protos_dot_model_dot_v1_dot_commands__pb2
from formant.protos.model.v1 import views_pb2 as protos_dot_model_dot_v1_dot_views__pb2
from formant.protos.model.v1 import ros_pb2 as protos_dot_model_dot_v1_dot_ros__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotos/model/v1/config.proto\x12\x08v1.model\x1a\x1eprotos/model/v1/commands.proto\x1a\x1bprotos/model/v1/views.proto\x1a\x19protos/model/v1/ros.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xeb\x01\n\x17\x41gentConfigurationStore\x12\x15\n\ragent_version\x18\x01 \x01(\t\x12\x33\n\rconfiguration\x18\x02 \x01(\x0b\x32\x1c.v1.model.AgentConfiguration\x12.\n\x0b\x66\x65\x61ture_set\x18\x03 \x01(\x0b\x32\x19.v1.model.AgentFeatureSet\x12,\n\x08\x63ommands\x18\x04 \x01(\x0b\x32\x1a.v1.model.CommandsMetadata\x12&\n\x05views\x18\x05 \x01(\x0b\x32\x17.v1.model.ViewsMetadata\"\x8d\x02\n\x0f\x41gentFeatureSet\x12\x11\n\ttelemetry\x18\x01 \x01(\x08\x12\x1a\n\x12internal_telemetry\x18\x02 \x01(\x08\x12\x0e\n\x06teleop\x18\x03 \x01(\x08\x12\x15\n\rcustom_events\x18\x04 \x01(\x08\x12\x18\n\x10triggered_events\x18\x05 \x01(\x08\x12\x0b\n\x03ssh\x18\x06 \x01(\x08\x12\x17\n\x0fport_forwarding\x18\x07 \x01(\x08\x12\x10\n\x08\x63ommands\x18\x08 \x01(\x08\x12\x15\n\rinterventions\x18\t \x01(\x08\x12\x11\n\ton_demand\x18\n \x01(\x08\x12\x12\n\napp_config\x18\x0b \x01(\x08\x12\x14\n\x0c\x62lob_storage\x18\x0c \x01(\x08\"f\n\x12\x41gentConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x08\x64ocument\x18\x03 \x01(\x0b\x32$.v1.model.AgentConfigurationDocument\"\xbc\x05\n\x1a\x41gentConfigurationDocument\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..v1.model.AgentConfigurationDocument.TagsEntry\x12\x33\n\ttelemetry\x18\x03 \x01(\x0b\x32 .v1.model.TelemetryConfiguration\x12\x33\n\tresources\x18\x04 \x01(\x0b\x32 .v1.model.ResourcesConfiguration\x12\x37\n\x0b\x61pplication\x18\x05 \x01(\x0b\x32\".v1.model.ApplicationConfiguration\x12-\n\x06teleop\x18\x06 \x01(\x0b\x32\x1d.v1.model.TeleopConfiguration\x12>\n\x0fport_forwarding\x18\x07 \x01(\x0b\x32%.v1.model.PortForwardingConfiguration\x12%\n\tblob_data\x18\x08 \x01(\x0b\x32\x12.v1.model.BlobData\x12*\n\x0b\x64iagnostics\x18\t \x01(\x0b\x32\x15.v1.model.Diagnostics\x12\x33\n\x0fterminal_access\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x08\x61\x64\x61pters\x18\x0b \x03(\x0b\x32\x1e.v1.model.AdapterConfiguration\x12#\n\x08rtc_info\x18\x0c \x01(\x0b\x32\x11.v1.model.RtcInfo\x12\x31\n\x08realtime\x18\r \x01(\x0b\x32\x1f.v1.model.RealtimeConfiguration\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14\x41\x64\x61pterConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x03 \x01(\t\x12\x14\n\x0c\x65xec_command\x18\x04 \x01(\t\x12\x15\n\rconfiguration\x18\x05 \x01(\t\"\xdc\x01\n\x13TeleopConfiguration\x12;\n\x0bros_streams\x18\x01 \x03(\x0b\x32&.v1.model.TeleopRosStreamConfiguration\x12\x41\n\x0e\x63ustom_streams\x18\x02 \x03(\x0b\x32).v1.model.TeleopCustomStreamConfiguration\x12\x45\n\x10hardware_streams\x18\x03 \x03(\x0b\x32+.v1.model.TeleopHardwareStreamConfiguration\"\xde\x01\n\x15RealtimeConfiguration\x12;\n\x0bros_streams\x18\x01 \x03(\x0b\x32&.v1.model.TeleopRosStreamConfiguration\x12\x41\n\x0e\x63ustom_streams\x18\x02 \x03(\x0b\x32).v1.model.TeleopCustomStreamConfiguration\x12\x45\n\x10hardware_streams\x18\x03 \x03(\x0b\x32+.v1.model.TeleopHardwareStreamConfiguration\"J\n\x1bPortForwardingConfiguration\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdf\x02\n\x1cTeleopRosStreamConfiguration\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12*\n\ntopic_type\x18\x02 \x01(\x0e\x32\x16.v1.model.ROSTopicType\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x14\n\x0c\x65ncode_video\x18\x04 \x01(\x08\x12\x13\n\x0b\x61udio_codec\x18\x05 \x01(\t\x12\x0f\n\x07quality\x18\x06 \x01(\t\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x07 \x01(\t\x12\x13\n\x0blocal_frame\x18\x08 \x01(\t\x12\x15\n\roverlay_clock\x18\t \x01(\x08\x12\x0f\n\x07\x62itrate\x18\n \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x0b \x01(\x08\x12\r\n\x05label\x18\x0c \x01(\t\x12\x13\n\x0bros_version\x18\r \x01(\t\"\xe8\x02\n!TeleopHardwareStreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0frtc_stream_type\x18\x02 \x01(\t\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x15\n\rhw_descriptor\x18\x04 \x01(\t\x12\x0f\n\x07quality\x18\x05 \x01(\t\x12\x15\n\rhardware_type\x18\x06 \x01(\t\x12\x1c\n\x14rtsp_encoding_needed\x18\x07 \x01(\x08\x12\x10\n\x08is_onvif\x18\x08 \x01(\x08\x12\x17\n\x0fip_cam_username\x18\t \x01(\t\x12\x17\n\x0fip_cam_password\x18\n \x01(\t\x12\x15\n\roverlay_clock\x18\x0b \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x0c \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\r \x01(\x08\x12\r\n\x05label\x18\x0e \x01(\t\"\xec\x01\n\x1fTeleopCustomStreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0frtc_stream_type\x18\x02 \x01(\t\x12\"\n\x04mode\x18\x03 \x01(\x0e\x32\x14.v1.model.TeleopMode\x12\x14\n\x0c\x65ncode_video\x18\x04 \x01(\x08\x12\x0f\n\x07quality\x18\x05 \x01(\t\x12\x15\n\roverlay_clock\x18\x06 \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x07 \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x08 \x01(\x08\x12\r\n\x05label\x18\t \x01(\t\"q\n\x16TelemetryConfiguration\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.v1.model.StreamConfiguration\x12\'\n\x03ros\x18\x02 \x01(\x0b\x32\x1a.v1.model.ROSConfiguration\"\xa8\x01\n\x18\x41pplicationConfiguration\x12S\n\x11\x63onfiguration_map\x18\x01 \x03(\x0b\x32\x38.v1.model.ApplicationConfiguration.ConfigurationMapEntry\x1a\x37\n\x15\x43onfigurationMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x02\n\x16ResourcesConfiguration\x12)\n\x04\x64isk\x18\x01 \x01(\x0b\x32\x1b.v1.model.DiskConfiguration\x12\x38\n\x12stream_throttle_hz\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x1b\n\x13low_bandwidth_agent\x18\x03 \x01(\x08\x12\x1c\n\x14\x64\x61tapoint_batch_size\x18\x04 \x01(\x04\x12\"\n\x1a\x64\x61tapoint_batchLifetime_ms\x18\x05 \x01(\x04\x12\x18\n\x10\x61sset_batch_size\x18\x06 \x01(\x04\x12\x1f\n\x17\x61sset_batch_lifetime_ms\x18\x07 \x01(\x04\"G\n\x11\x44iskConfiguration\x12\x13\n\x0b\x62uffer_size\x18\x01 \x01(\x03\x12\x1d\n\x15on_demand_buffer_size\x18\x02 \x01(\x03\"4\n\x10ROSConfiguration\x12 \n\x18world_reference_frame_id\x18\x01 \x01(\t\"\xb8\x05\n\x13StreamConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x04tags\x18\x02 \x03(\x0b\x32\'.v1.model.StreamConfiguration.TagsEntry\x12\'\n\tros_topic\x18\x03 \x01(\x0b\x32\x12.v1.model.ROSTopicH\x00\x12\x35\n\x10ros_localization\x18\x04 \x01(\x0b\x32\x19.v1.model.ROSLocalizationH\x00\x12\x33\n\x0f\x64irectory_watch\x18\x05 \x01(\x0b\x32\x18.v1.model.DirectoryWatchH\x00\x12\'\n\tfile_tail\x18\x06 \x01(\x0b\x32\x12.v1.model.FileTailH\x00\x12\x38\n\x12ros_transform_tree\x18\x07 \x01(\x0b\x32\x1a.v1.model.ROSTransformTreeH\x00\x12\"\n\x06\x63ustom\x18\t \x01(\x0b\x32\x10.v1.model.CustomH\x00\x12&\n\x08hardware\x18\n \x01(\x0b\x32\x12.v1.model.HardwareH\x00\x12\x31\n\x0bthrottle_hz\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x08\x64isabled\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\ton_demand\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\ttransform\x18\x15 \x01(\x0b\x32&.v1.model.StreamTransformConfiguration\x12\x0f\n\x07quality\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rconfiguration\"Z\n\x1cStreamTransformConfiguration\x12:\n\x16video_encoding_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x18\n\x08\x42lobData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"r\n\x0b\x44iagnostics\x12/\n\x0breport_logs\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ereport_metrics\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x08\n\x06\x43ustom\"\x81\x02\n\x08Hardware\x12\x15\n\rhw_descriptor\x18\x01 \x01(\t\x12\x1b\n\x13\x61udio_hw_descriptor\x18\x03 \x01(\t\x12\x15\n\rhardware_type\x18\x04 \x01(\t\x12\x1c\n\x14rtsp_encoding_needed\x18\x05 \x01(\x08\x12\x10\n\x08is_onvif\x18\x06 \x01(\x08\x12\x17\n\x0fip_cam_username\x18\x07 \x01(\t\x12\x17\n\x0fip_cam_password\x18\x08 \x01(\t\x12\x15\n\roverlay_clock\x18\t \x01(\x08\x12\x0f\n\x07\x62itrate\x18\n \x01(\x03\x12 \n\x18\x64isable_adaptive_quality\x18\x0b \x01(\x08\"s\n\x0e\x44irectoryWatch\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x11\n\textension\x18\x02 \x01(\t\x12%\n\tfile_type\x18\x03 \x01(\x0e\x32\x12.v1.model.FileType\x12\x14\n\x0cremote_agent\x18\x04 \x01(\x08\"}\n\x08\x46ileTail\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12)\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x14.v1.model.FileFormat\x12\x10\n\x08time_key\x18\x03 \x01(\t\x12\x13\n\x0btime_format\x18\x04 \x01(\t\x12\r\n\x05regex\x18\x05 \x01(\t\"g\n\x07RtcInfo\x12\"\n\x1artc_ice_transport_policies\x18\x01 \x03(\t\x12\x1f\n\x17rtc_ice_server_protocol\x18\x02 \x01(\t\x12\x17\n\x0fuse_all_servers\x18\x03 \x01(\x08*&\n\nTeleopMode\x12\x0b\n\x07\x43OMMAND\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01*&\n\nFileFormat\x12\x0e\n\nPLAIN_TEXT\x10\x00\x12\x08\n\x04JSON\x10\x01*;\n\x08\x46ileType\x12\x08\n\x04\x46ILE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0f\n\x0bPOINT_CLOUD\x10\x04\x12\t\n\x05VIDEO\x10\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._loaded_options = None
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._loaded_options = None
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_options = b'8\001'
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._loaded_options = None
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_TELEOPMODE']._serialized_start=5318
  _globals['_TELEOPMODE']._serialized_end=5356
  _globals['_FILEFORMAT']._serialized_start=5358
  _globals['_FILEFORMAT']._serialized_end=5396
  _globals['_FILETYPE']._serialized_start=5398
  _globals['_FILETYPE']._serialized_end=5457
  _globals['_AGENTCONFIGURATIONSTORE']._serialized_start=163
  _globals['_AGENTCONFIGURATIONSTORE']._serialized_end=398
  _globals['_AGENTFEATURESET']._serialized_start=401
  _globals['_AGENTFEATURESET']._serialized_end=670
  _globals['_AGENTCONFIGURATION']._serialized_start=672
  _globals['_AGENTCONFIGURATION']._serialized_end=774
  _globals['_AGENTCONFIGURATIONDOCUMENT']._serialized_start=777
  _globals['_AGENTCONFIGURATIONDOCUMENT']._serialized_end=1477
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_start=1434
  _globals['_AGENTCONFIGURATIONDOCUMENT_TAGSENTRY']._serialized_end=1477
  _globals['_ADAPTERCONFIGURATION']._serialized_start=1479
  _globals['_ADAPTERCONFIGURATION']._serialized_end=1589
  _globals['_TELEOPCONFIGURATION']._serialized_start=1592
  _globals['_TELEOPCONFIGURATION']._serialized_end=1812
  _globals['_REALTIMECONFIGURATION']._serialized_start=1815
  _globals['_REALTIMECONFIGURATION']._serialized_end=2037
  _globals['_PORTFORWARDINGCONFIGURATION']._serialized_start=2039
  _globals['_PORTFORWARDINGCONFIGURATION']._serialized_end=2113
  _globals['_TELEOPROSSTREAMCONFIGURATION']._serialized_start=2116
  _globals['_TELEOPROSSTREAMCONFIGURATION']._serialized_end=2467
  _globals['_TELEOPHARDWARESTREAMCONFIGURATION']._serialized_start=2470
  _globals['_TELEOPHARDWARESTREAMCONFIGURATION']._serialized_end=2830
  _globals['_TELEOPCUSTOMSTREAMCONFIGURATION']._serialized_start=2833
  _globals['_TELEOPCUSTOMSTREAMCONFIGURATION']._serialized_end=3069
  _globals['_TELEMETRYCONFIGURATION']._serialized_start=3071
  _globals['_TELEMETRYCONFIGURATION']._serialized_end=3184
  _globals['_APPLICATIONCONFIGURATION']._serialized_start=3187
  _globals['_APPLICATIONCONFIGURATION']._serialized_end=3355
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_start=3300
  _globals['_APPLICATIONCONFIGURATION_CONFIGURATIONMAPENTRY']._serialized_end=3355
  _globals['_RESOURCESCONFIGURATION']._serialized_start=3358
  _globals['_RESOURCESCONFIGURATION']._serialized_end=3637
  _globals['_DISKCONFIGURATION']._serialized_start=3639
  _globals['_DISKCONFIGURATION']._serialized_end=3710
  _globals['_ROSCONFIGURATION']._serialized_start=3712
  _globals['_ROSCONFIGURATION']._serialized_end=3764
  _globals['_STREAMCONFIGURATION']._serialized_start=3767
  _globals['_STREAMCONFIGURATION']._serialized_end=4463
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_start=1434
  _globals['_STREAMCONFIGURATION_TAGSENTRY']._serialized_end=1477
  _globals['_STREAMTRANSFORMCONFIGURATION']._serialized_start=4465
  _globals['_STREAMTRANSFORMCONFIGURATION']._serialized_end=4555
  _globals['_BLOBDATA']._serialized_start=4557
  _globals['_BLOBDATA']._serialized_end=4581
  _globals['_DIAGNOSTICS']._serialized_start=4583
  _globals['_DIAGNOSTICS']._serialized_end=4697
  _globals['_CUSTOM']._serialized_start=4699
  _globals['_CUSTOM']._serialized_end=4707
  _globals['_HARDWARE']._serialized_start=4710
  _globals['_HARDWARE']._serialized_end=4967
  _globals['_DIRECTORYWATCH']._serialized_start=4969
  _globals['_DIRECTORYWATCH']._serialized_end=5084
  _globals['_FILETAIL']._serialized_start=5086
  _globals['_FILETAIL']._serialized_end=5211
  _globals['_RTCINFO']._serialized_start=5213
  _globals['_RTCINFO']._serialized_end=5316
# @@protoc_insertion_point(module_scope)
