# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/views.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/views.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprotos/model/v1/views.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\x1a\x1cgoogle/protobuf/struct.proto\"6\n\rViewsMetadata\x12%\n\x05views\x18\x01 \x03(\x0b\x32\x16.v1.model.ViewMetadata\"\xb5\x04\n\x0cViewMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x04tags\x18\x02 \x03(\x0b\x32 .v1.model.ViewMetadata.TagsEntry\x12\x16\n\x0eorganizationId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x1a\n\x12showOnSingleDevice\x18\x07 \x01(\x08\x12\x19\n\x11showOnMultiDevice\x18\x08 \x01(\x08\x12\x14\n\x0cshowOnTeleop\x18\t \x01(\x08\x12\x14\n\x0cshowTimeline\x18\x0b \x01(\x08\x12 \n\x06\x66ilter\x18\x0c \x01(\x0b\x32\x10.v1.model.Filter\x12\'\n\x06layout\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nlayoutType\x18\x0e \x01(\t\x12\x32\n\rconfiguration\x18\x0f \x03(\x0b\x32\x1b.v1.model.ViewConfiguration\x12\x14\n\x0csmartFleetId\x18\x10 \x01(\t\x12\r\n\x05index\x18\x11 \x01(\x03\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\nLayoutType\x12\r\n\tDASHBOARD\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01\x12\x0e\n\nFULLSCREEN\x10\x02\x12\r\n\tANALYTICS\x10\x03\x12\n\n\x06TELEOP\x10\x04J\x04\x08\n\x10\x0b\"\x94\x02\n\x06\x46ilter\x12(\n\x04tags\x18\x01 \x03(\x0b\x32\x1a.v1.model.Filter.TagsEntry\x12\r\n\x05names\x18\x02 \x03(\t\x12\r\n\x05types\x18\x03 \x03(\t\x12\x11\n\tdeviceIds\x18\x04 \x03(\t\x12.\n\x07notTags\x18\x05 \x03(\x0b\x32\x1d.v1.model.Filter.NotTagsEntry\x12\x10\n\x08notNames\x18\x06 \x03(\t\x12\x10\n\x08\x61gentIds\x18\x07 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cNotTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x11ViewConfiguration\x12\x12\n\nstreamName\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\rconfiguration\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.views_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_VIEWMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_FILTER_TAGSENTRY']._loaded_options = None
  _globals['_FILTER_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_FILTER_NOTTAGSENTRY']._loaded_options = None
  _globals['_FILTER_NOTTAGSENTRY']._serialized_options = b'8\001'
  _globals['_VIEWSMETADATA']._serialized_start=137
  _globals['_VIEWSMETADATA']._serialized_end=191
  _globals['_VIEWMETADATA']._serialized_start=194
  _globals['_VIEWMETADATA']._serialized_end=759
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_start=625
  _globals['_VIEWMETADATA_TAGSENTRY']._serialized_end=668
  _globals['_VIEWMETADATA_LAYOUTTYPE']._serialized_start=670
  _globals['_VIEWMETADATA_LAYOUTTYPE']._serialized_end=753
  _globals['_FILTER']._serialized_start=762
  _globals['_FILTER']._serialized_end=1038
  _globals['_FILTER_TAGSENTRY']._serialized_start=625
  _globals['_FILTER_TAGSENTRY']._serialized_end=668
  _globals['_FILTER_NOTTAGSENTRY']._serialized_start=992
  _globals['_FILTER_NOTTAGSENTRY']._serialized_end=1038
  _globals['_VIEWCONFIGURATION']._serialized_start=1040
  _globals['_VIEWCONFIGURATION']._serialized_end=1141
# @@protoc_insertion_point(module_scope)
