# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/intervention.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/intervention.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2
from formant.protos.model.v1 import event_pb2 as protos_dot_model_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"protos/model/v1/intervention.proto\x12\x08v1.model\x1a\x1bprotos/model/v1/media.proto\x1a\x1bprotos/model/v1/event.proto\"\x9c\x03\n\x13InterventionRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12$\n\x08severity\x18\x03 \x01(\x0e\x32\x12.v1.model.Severity\x12\x37\n\x11selection_request\x18\x04 \x01(\x0b\x32\x1a.v1.model.SelectionRequestH\x00\x12\x35\n\x10labeling_request\x18\x05 \x01(\x0b\x32\x19.v1.model.LabelingRequestH\x00\x12\x31\n\x0eteleop_request\x18\x08 \x01(\x0b\x32\x17.v1.model.TeleopRequestH\x00\x12\x35\n\x04tags\x18\x06 \x03(\x0b\x32\'.v1.model.InterventionRequest.TagsEntry\x12\x31\n\tresponses\x18\x07 \x03(\x0b\x32\x1e.v1.model.InterventionResponse\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x64\x61ta\"\xfa\x01\n\x14InterventionResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x39\n\x12selection_response\x18\x04 \x01(\x0b\x32\x1b.v1.model.SelectionResponseH\x00\x12\x37\n\x11labeling_response\x18\x05 \x01(\x0b\x32\x1a.v1.model.LabelingResponseH\x00\x12\x33\n\x0fteleop_response\x18\x06 \x01(\x0b\x32\x18.v1.model.TeleopResponseH\x00\x42\x06\n\x04\x64\x61ta\",\n\x05Label\x12\r\n\x05value\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"D\n\x0eLabeledPolygon\x12\"\n\x08vertices\x18\x01 \x03(\x0b\x32\x10.v1.model.Vertex\x12\x0e\n\x06labels\x18\x02 \x03(\t\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x9e\x01\n\x0fLabelingRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0binstruction\x18\x02 \x01(\t\x12\x1e\n\x05image\x18\x03 \x01(\x0b\x32\x0f.v1.model.Image\x12\x1f\n\x06labels\x18\x04 \x03(\x0b\x32\x0f.v1.model.Label\x12&\n\x04hint\x18\x05 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\";\n\x10LabelingResponse\x12\'\n\x05value\x18\x01 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\"\x7f\n\x10SelectionRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12 \n\x05image\x18\x02 \x01(\x0b\x32\x0f.v1.model.ImageH\x00\x12\x13\n\x0binstruction\x18\x03 \x01(\t\x12\x0f\n\x07options\x18\x04 \x03(\t\x12\x0c\n\x04hint\x18\x05 \x01(\rB\x06\n\x04\x64\x61ta\"\"\n\x11SelectionResponse\x12\r\n\x05value\x18\x01 \x01(\r\"$\n\rTeleopRequest\x12\x13\n\x0binstruction\x18\x01 \x01(\t\".\n\x0eTeleopResponse\x12\r\n\x05state\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x02 \x01(\tB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.intervention_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_INTERVENTIONREQUEST']._serialized_start=107
  _globals['_INTERVENTIONREQUEST']._serialized_end=519
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_start=468
  _globals['_INTERVENTIONREQUEST_TAGSENTRY']._serialized_end=511
  _globals['_INTERVENTIONRESPONSE']._serialized_start=522
  _globals['_INTERVENTIONRESPONSE']._serialized_end=772
  _globals['_LABEL']._serialized_start=774
  _globals['_LABEL']._serialized_end=818
  _globals['_LABELEDPOLYGON']._serialized_start=820
  _globals['_LABELEDPOLYGON']._serialized_end=888
  _globals['_VERTEX']._serialized_start=890
  _globals['_VERTEX']._serialized_end=920
  _globals['_LABELINGREQUEST']._serialized_start=923
  _globals['_LABELINGREQUEST']._serialized_end=1081
  _globals['_LABELINGRESPONSE']._serialized_start=1083
  _globals['_LABELINGRESPONSE']._serialized_end=1142
  _globals['_SELECTIONREQUEST']._serialized_start=1144
  _globals['_SELECTIONREQUEST']._serialized_end=1271
  _globals['_SELECTIONRESPONSE']._serialized_start=1273
  _globals['_SELECTIONRESPONSE']._serialized_end=1307
  _globals['_TELEOPREQUEST']._serialized_start=1309
  _globals['_TELEOPREQUEST']._serialized_end=1345
  _globals['_TELEOPRESPONSE']._serialized_start=1347
  _globals['_TELEOPRESPONSE']._serialized_end=1393
# @@protoc_insertion_point(module_scope)
