# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/ros.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/ros.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19protos/model/v1/ros.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\"P\n\x08ROSTopic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x65ncode_video\x18\x03 \x01(\x08\x12\x12\n\nrosVersion\x18\x04 \x01(\t\"\xae\x01\n\x0fROSLocalization\x12\x11\n\tmap_topic\x18\x01 \x01(\t\x12\x12\n\nodom_topic\x18\x02 \x01(\t\x12\x1a\n\x12point_cloud_topics\x18\x03 \x03(\t\x12\x12\n\npath_topic\x18\x04 \x01(\t\x12\x12\n\ngoal_topic\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x06 \x01(\t\x12\x12\n\nrosVersion\x18\x07 \x01(\t\"0\n\x10ROSTransformTree\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x01 \x01(\t\"\x9d\x03\n\x13ROSMessageToPublish\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12 \n\x05twist\x18\x02 \x01(\x0b\x32\x0f.v1.model.TwistH\x00\x12\x0e\n\x04\x62ool\x18\x03 \x01(\x08H\x00\x12\x1a\n\x10\x63ompressed_image\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04text\x18\x05 \x01(\tH\x00\x12#\n\x04pose\x18\x06 \x01(\x0b\x32\x13.v1.model.TransformH\x00\x12\"\n\x06goalID\x18\t \x01(\x0b\x32\x10.v1.model.GoalIDH\x00\x12$\n\x07numeric\x18\n \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12<\n\x14pose_with_covariance\x18\x0b \x01(\x0b\x32\x1c.v1.model.PoseWithCovarianceH\x00\x12 \n\x05point\x18\x0c \x01(\x0b\x32\x0f.v1.model.PointH\x00\x12\x1c\n\x03joy\x18\r \x01(\x0b\x32\r.v1.model.JoyH\x00\x42\x06\n\x04\x64\x61ta*\xd7\x03\n\x0cROSTopicType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rSTD_MSGS_BOOL\x10\x01\x12 \n\x1cSENSOR_MSGS_COMPRESSED_IMAGE\x10\x02\x12\x13\n\x0fSTD_MSGS_STRING\x10\x03\x12\x16\n\x12GEOMETRY_MSGS_POSE\x10\x04\x12\x19\n\x15\x41\x43TIONLIB_MSGS_GOALID\x10\x05\x12\x17\n\x13GEOMETRY_MSGS_TWIST\x10\x06\x12\x14\n\x10H264_VIDEO_FRAME\x10\x07\x12\x0f\n\x0b\x41UDIO_CHUNK\x10\x08\x12\x14\n\x10STD_MSGS_FLOAT64\x10\t\x12\x1b\n\x17SENSOR_MSGS_JOINT_STATE\x10\n\x12&\n\"GEOMETRY_MSGS_POSE_WITH_COVARIANCE\x10\x0b\x12\x1c\n\x18SENSOR_MSGS_POINT_CLOUD2\x10\x0c\x12\x1a\n\x16SENSOR_MSGS_LASER_SCAN\x10\r\x12\x17\n\x13GEOMETRY_MSGS_POINT\x10\x0e\x12#\n\x1fVISUALIZATION_MSGS_MARKER_ARRAY\x10\x0f\x12\x15\n\x11NAV_MSGS_ODOMETRY\x10\x10\x12\x13\n\x0fSENSOR_MSGS_JOY\x10\x11\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.ros_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_ROSTOPICTYPE']._serialized_start=827
  _globals['_ROSTOPICTYPE']._serialized_end=1298
  _globals['_ROSTOPIC']._serialized_start=101
  _globals['_ROSTOPIC']._serialized_end=181
  _globals['_ROSLOCALIZATION']._serialized_start=184
  _globals['_ROSLOCALIZATION']._serialized_end=358
  _globals['_ROSTRANSFORMTREE']._serialized_start=360
  _globals['_ROSTRANSFORMTREE']._serialized_end=408
  _globals['_ROSMESSAGETOPUBLISH']._serialized_start=411
  _globals['_ROSMESSAGETOPUBLISH']._serialized_end=824
# @@protoc_insertion_point(module_scope)
