# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/health.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/health.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotos/model/v1/health.proto\x12\x08v1.model\"L\n\x06Health\x12&\n\x06status\x18\x01 \x01(\x0e\x32\x16.v1.model.HealthStatus\x12\x11\n\x07skew_ms\x18\x02 \x01(\x03H\x00\x42\x07\n\x05\x63lock\"O\n\x07\x42\x61ttery\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x0f\n\x07voltage\x18\x02 \x01(\x01\x12\x0f\n\x07\x63urrent\x18\x03 \x01(\x01\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x01\"\xf4\x01\n\x0e\x42ufferMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x30\n(latest_ttl_stream_channel_buffered_bytes\x18\x02 \x01(\x04\x12.\n&reliable_stream_channel_buffered_bytes\x18\x03 \x01(\x04\x12\x35\n-latest_reliable_stream_channel_buffered_bytes\x18\x04 \x01(\x04\x12\x35\n-latest_try_once_stream_channel_buffered_bytes\x18\x05 \x01(\x04*`\n\x0cHealthStatus\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\x16\n\x12HEALTH_OPERATIONAL\x10\x01\x12\x12\n\x0eHEALTH_OFFLINE\x10\x02\x12\x10\n\x0cHEALTH_ERROR\x10\x03\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.health_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_HEALTHSTATUS']._serialized_start=448
  _globals['_HEALTHSTATUS']._serialized_end=544
  _globals['_HEALTH']._serialized_start=42
  _globals['_HEALTH']._serialized_end=118
  _globals['_BATTERY']._serialized_start=120
  _globals['_BATTERY']._serialized_end=199
  _globals['_BUFFERMETADATA']._serialized_start=202
  _globals['_BUFFERMETADATA']._serialized_end=446
# @@protoc_insertion_point(module_scope)
