# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/model/v1/commands.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'protos/model/v1/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprotos/model/v1/commands.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\"\xd0\x01\n\x0e\x43ommandRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x0e\n\x04text\x18\x03 \x01(\tH\x00\x12\x31\n\rscrubber_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05\x66iles\x18\x05 \x03(\x0b\x32\x12.v1.model.FileInfo\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0b\n\tparameter\"j\n\x0f\x43ommandResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12(\n\tdatapoint\x18\x03 \x01(\x0b\x32\x13.v1.model.DatapointH\x00\x42\x08\n\x06result\"1\n\x08\x46ileInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"?\n\x10\x43ommandsMetadata\x12+\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x19.v1.model.CommandMetadata\"\xf2\x02\n\x0f\x43ommandMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11parameter_enabled\x18\x04 \x01(\x08\x12\x17\n\x0fparameter_value\x18\x05 \x01(\t\x12\x44\n\x0eparameter_meta\x18\x06 \x03(\x0b\x32,.v1.model.CommandMetadata.ParameterMetaEntry\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12\n\n\x02id\x18\x08 \x01(\t\x12\x31\n\x04tags\x18\t \x03(\x0b\x32#.v1.model.CommandMetadata.TagsEntry\x1a\x34\n\x12ParameterMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.model.v1.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/FormantIO/genproto/go/v1/model'
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._loaded_options = None
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDREQUEST']._serialized_start=111
  _globals['_COMMANDREQUEST']._serialized_end=319
  _globals['_COMMANDRESPONSE']._serialized_start=321
  _globals['_COMMANDRESPONSE']._serialized_end=427
  _globals['_FILEINFO']._serialized_start=429
  _globals['_FILEINFO']._serialized_end=478
  _globals['_COMMANDSMETADATA']._serialized_start=480
  _globals['_COMMANDSMETADATA']._serialized_end=543
  _globals['_COMMANDMETADATA']._serialized_start=546
  _globals['_COMMANDMETADATA']._serialized_end=916
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_start=819
  _globals['_COMMANDMETADATA_PARAMETERMETAENTRY']._serialized_end=871
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_start=873
  _globals['_COMMANDMETADATA_TAGSENTRY']._serialized_end=916
# @@protoc_insertion_point(module_scope)
