from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceTags, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceStreamRosTransformTreeConfigurationType, DeviceTeleopCustomStreamConfigurationMode, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceTeleopRosStreamConfiguration, DeviceTeleopRosStreamConfigurationMode, KernelInfo, DeviceFollower, OnvifDevice, DeviceTeleopCustomStreamConfiguration, DeviceStreamConfigurationQuality, OnDemandPresenceStreamItemGroupDatapointType, DeviceDetailsTags, DeviceConfigurationTemplate, DeviceStreamRosTopicConfigurationType, DeviceType, DeviceOnlineEventMetadata, DeviceDetails, DeviceOnlineEventStreamType, AudioDevice, ScopeFilterTypesItem, OnDemandState, DeviceStreamHardwareConfigurationType, DeviceOfflineEventSeverity, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceApplicationConfiguration, VideoDevice, RtcInfoRtcIceTransportPoliciesItem, DeviceStreamConfiguration, DeviceStreamCustomConfiguration, OnDemandPresenceTimeRange, DeviceTeleopHardwareStreamConfigurationMode, DeviceDetailsSort, OnDemandBufferBufferType, DeviceStreamTransformConfiguration, RtcInfoRtcIceServerProtocol, DeviceStreamHardwareConfigurationHardwareType, TeleopJoystickConfiguration, DeviceTeleopRosStreamConfigurationTopicType, TeleopJoystickAxisConfigurationDimension, DeviceTeleopConfiguration, DeviceOnlineEvent, DeviceStreamDirectoryWatchConfiguration, DeviceOnlineEventSeverity, DeviceConfigurationTemplateListResponse, DeviceTeleopHardwareStreamConfiguration, DeviceStateEnv, DeviceProvisioning, DeviceStreamFileTailConfigurationFileFormat, DeviceRosConfiguration, DeviceStreamDirectoryWatchConfigurationFileType, PartialDeviceTags, DeviceRealtimeConfiguration, ScopeFilter, DeviceConfigurationTemplateTags, DeviceState, DeviceConfiguration, DeviceRosState, DeviceTeleopCustomStreamConfigurationRtcStreamType, DevicePortForwardingConfiguration, DeviceDetailsType, DeviceTelemetryConfiguration, DeviceBlobData, DeviceListResponse, OnDemandStreamPresence, PartialDeviceType, DeviceOfflineEventTags, DeviceReportedConfigurationState, TeleopJoystickConfigurationPosition, NodeInfo, DeviceScope, DeviceOnlineEventTags, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceDetailsSortColumn, DeviceCredentials, TeleopJoystickAxisConfiguration, DeviceOfflineEvent, DeviceConfigurationDocumentTags, DeviceDiskConfiguration, DeviceStreamRosLocalizationConfigurationRosVersion, DeviceOnlineEventType, NetworkInfo, OsInfo, DeviceStreamRosLocalizationConfiguration, DeviceResourcesConfiguration, DeviceStreamDirectoryWatchConfigurationType, HwInfo, DeviceStreamRosLocalizationConfigurationType, PartialDevice, DeviceStreamRosTopicConfigurationRosVersion, TeleopViewConfiguration, DeviceScopeTypesItem, DeviceStreamConfigurationTags, DeviceStreamHardwareConfiguration, DeviceStreamCustomConfigurationType, DeviceQuery, OnDemandPresenceStreamItemGroup, AdapterConfiguration, DeviceApplicationConfigurationConfigurationMap, DeviceOfflineEventType, DeviceOfflineEventMetadata, DeviceDetailsSortOrder, DeviceOfflineEventStreamType, DeviceProvisioningRequest, DeviceStreamRosTransformTreeConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceStreamFileTailConfiguration, DeviceTeleopRosStreamConfigurationQuality, Network, RosTopic, CommandProgress, DeviceTeleopRosStreamConfigurationAudioCodec, DeviceQueryType, DeviceTeleopHardwareStreamConfigurationQuality, DeviceConfigurationDocument, DeviceDetailsListResponse, RtcInfo, Device, DeviceStreamRosTopicConfiguration, DeviceStreamHardwareConfigurationQuality, DeviceDiagnosticsConfiguration, OnDemandBuffer, ValidationConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceStreamFileTailConfigurationType
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional